@@ -20,9 +20,9 @@
  * Author: Carl-Anton Ingmarsson <ca.ingmarsson@gmail.com>
  */
 
-#include <stdlib.h>
 #include <string.h>
 #include <glib/gi18n.h>
+#include <gio/gnetworking.h>
 
 
 #include "gvfsafpconnection.h"
@@ -879,12 +879,6 @@ read_all_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
     g_simple_async_result_take_error (simple, err);
     goto done;
   }
-  else if (bytes_read == 0)
-  {
-    g_simple_async_result_set_error (simple, G_IO_ERROR, G_IO_ERROR_CLOSED,
-                                     _("Got EOS"));
-    goto done;
-  }
 
   read_data = g_simple_async_result_get_op_res_gpointer (simple);
 
@@ -1055,15 +1049,8 @@ read_data_cb (GObject *object, GAsyncResult *res, gpointer user_data)
   result = read_all_finish (input, res, NULL, &err);
   if (!result)
   {
-    if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CLOSED))
-    {
-      g_message (_("Host closed connection"));
-      exit(0);
-    }
-    else
-    {
-      g_error ("FAIL!!! \"%s\"\n", err->message);
-    }
+    g_warning ("FAIL!!! \"%s\"\n", err->message);
+    g_error_free (err);
   }
 
   dispatch_reply (afp_connection);
@@ -1096,15 +1083,8 @@ read_dsi_header_cb (GObject *object, GAsyncResult *res, gpointer user_data)
   result = read_all_finish (input, res, NULL, &err);
   if (!result)
   {
-    if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CLOSED))
-    {
-      g_message (_("Host closed connection"));
-      exit(0);
-    }
-    else
-    {
-      g_error ("FAIL!!! \"%s\"\n", err->message);
-    }
+    g_warning ("FAIL!!! \"%s\"\n", err->message);
+    g_error_free (err);
   }
 
   dsi_header = &priv->read_dsi_header;
@@ -1791,6 +1771,9 @@ open_thread_func (gpointer user_data)
   GVfsAfpConnectionPrivate *priv = conn->priv;
 
   GSocketClient *client;
+  GSocketConnection *connection;
+  GSocket *socket;
+  GError *error = NULL;
 
   guint16 req_id;
   gboolean res = FALSE;
@@ -1799,13 +1782,22 @@ open_thread_func (gpointer user_data)
   guint pos;
 
   client = g_socket_client_new ();
-  priv->stream = G_IO_STREAM (g_socket_client_connect (client, priv->addr, data->cancellable,
-                                                       data->error));
+  connection = g_socket_client_connect (client,
+                                        priv->addr,
+                                        data->cancellable, data->error);
   g_object_unref (client);
 
-  if (!priv->stream)
+  if (!connection)
     goto out;
 
+  socket = g_socket_connection_get_socket (connection);
+  if (!g_socket_set_option (socket, IPPROTO_TCP, TCP_NODELAY, TRUE, &error))
+  {
+    g_warning ("Could not set TCP_NODELAY: %s\n", error->message);
+    g_error_free (error);
+  }
+  priv->stream = G_IO_STREAM (connection);
+
   req_id = get_request_id (conn);
   res = send_request_sync (g_io_stream_get_output_stream (priv->stream),
                            DSI_OPEN_SESSION, req_id, 0,  0, NULL,
